@@ -33,10 +33,27 @@ IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
 
+__all__ = [
+    'GNServer',
+    'App',
+    'Url',
+    'GNRequest',
+    'GNResponse',
+    'CommandObject',
+    'CORSObject',
+    'FileObject',
+    'TemplateObject',
+    'GNTransportProtocol',
+    'AsyncClient',
+    'response'
+]
+
+from ._gnserver import GNServer
 from ._app import App
 
 from gnobjects.net.objects import Url, GNRequest, GNResponse, CommandObject, CORSObject, FileObject, TemplateObject, GNTransportProtocol
-from gnobjects.net.objects import AllGNFastCommands as responses
+from gnobjects.net.objects import AllGNFastCommands as response
 
+responses = response
 
 from ._client import AsyncClient
