@@ -1,11 +1,12 @@
 import os
+import sys
 import time
 import httpx
 import asyncio
 import datetime
 from itertools import count
 from collections import deque
-from typing import Any, Dict, Deque, Tuple, Union, Optional, AsyncGenerator, Callable, Literal, AsyncIterable
+from typing import Any, Dict, Deque, Tuple, Union, Optional, AsyncGenerator, Callable, Literal, AsyncIterable, overload
 from aioquic.quic.events import QuicEvent, StreamDataReceived, StreamReset, ConnectionTerminated
 from aioquic.quic.configuration import QuicConfiguration
 from aioquic.asyncio.client import connect
@@ -13,6 +14,7 @@ from aioquic.asyncio.protocol import QuicConnectionProtocol
 
 
 
+
 class GNExceptions:
     class ConnectionError:
         class openconnector():
@@ -84,59 +86,56 @@ from KeyisBTools.ranges.positionRange import in_range
 from gnobjects.net.objects import GNRequest, GNResponse, Url
 
 from ._crt import crt_client
+from .models import KDCObject
+from ._datagram_enc import EncryptedQuicProtocol, DatagramEncryptor
+
+import traceback
+
+import logging
+
+logger = logging.getLogger("GNClient")
+logger.setLevel(logging.DEBUG)
+logger.propagate = False
+# --- Удаляем все старые хендлеры, чтобы не было дублей ---
+if logger.hasHandlers():
+    logger.handlers.clear()
+
+# --- Добавляем новый консольный хендлер ---
+console = logging.StreamHandler(sys.stdout)
+console.setLevel(logging.DEBUG)
+
+# Формат с временем
+formatter = logging.Formatter(
+    "[%(asctime)s] [%(name)s] %(levelname)s: %(message)s",
+    datefmt="%Y-%m-%d %H:%M:%S"
+)
+console.setFormatter(formatter)
+
+logger.addHandler(console)
 
 
 
-_log_levels: dict[str, int] = {
-    "NOTSET": 0,
-    "DEBUG": 10,
-    "INFO": 20,
-    "WARNING": 30,
-    "ERROR": 40,
-    "CRITICAL": 50,
-    "notset": 0,
-    "debug": 10,
-    "info": 20,
-    "warning": 30,
-    "error": 40,
-    "critical": 50,
-}
-
-def devLog(request: GNRequest, point: str, level: int, log: str):
-    """
-- NOTSET	 0
-- DEBUG	     10
-- INFO	     20
-- WARNING	 30
-- ERROR	     40
-- CRITICAL   50
-    """
-    if request.transportObject.routeProtocol.dev:
-        if hasattr(request, '_devDataLog'):
-            if request._devDataLogLevel <= level:
-                if in_range(point, request._devDataRange):
-
-                    log = f'[{level}]({datetime.datetime.now()}): {log}'
-
-                    request._devDataLog.append(log)
-
-
-
-
-
-
-
-
+_sys_s_mode = 2
 
 async def chain_async(first_item, rest: AsyncIterable) -> AsyncGenerator:
     yield first_item
     async for x in rest:
         yield x
 
+"""
+L1 - Physical
+L2 - MAC
+L3 - IP
+L4 - TCP/UDP
+L5 - quic(packet managment)
+L6 - GN(protocol managment)
+
+
+"""
 
 
 class AsyncClient:
-    def __init__(self, server_key: Optional[Union[bytes, str]] = None):
+    def __init__(self, domain: str = 'unknown', server_key: Optional[Union[bytes, str]] = None):
         self.__dns_core__ipv4 = '51.250.85.38:52943'
         self.__dns_gn__ipv4: Optional[str] = None
 
@@ -149,109 +148,49 @@ class AsyncClient:
         self.__dns_client: Optional[AsyncClient] = None
         self._dns_cache: TTLDict = TTLDict()
 
+        self._domain = domain
+
+        self._kdc: Optional[KDCObject] = None
+
+        
         if server_key:
-            if isinstance(server_key, bytes):
-                self.__server_key = server_key
+            self.setDNSkey(server_key)
+        else:
+            self._dns_key = None
+
+        self._configuration: dict = {
+            'L5': {
+                'connection': {
+                    'connect_timeout': 10,
+                },
+                'disconnection': {
+                    'idle_timeout': 60,
+                    'ping_interval': 15,
+                    'ping_check_interval': 5,
+                }
+            }
+        }
+
+    
+    def setConfiguration(self, configuration: dict):
+        self._configuration = configuration
+
+
+    def setDNSkey(self, key: Union[bytes, str]):
+        if key:
+            if isinstance(key, bytes):
+                self._dns_key = key
             else:
-                if os.path.exists(server_key):
-                    self.__server_key = open(server_key, 'rb').read()
+                if os.path.exists(key):
+                    self._dns_key = open(key, 'rb').read()
                 else:
-                    self.__server_key = userFriendly.decode(server_key)
+                    self._dns_key = userFriendly.decode(key)
         else:
-            self.__server_key = None
+            self._dns_key = None
 
-    async def getCoreDNS(self, domain: str, use_cache: bool = True, keep_alive: bool = False) -> str:
-        if use_cache:
-            resuilt = self._dns_cache.get(domain)
-            if resuilt is not None:
-                return resuilt
-            
-        if domain == 'api.dns.core':
-            return self.__dns_core__ipv4
-
-        if ':' in domain and domain.split('.')[-1].split(':')[0].isdigit() and domain.split(':')[-1].isdigit():
-            return domain
-
-        try:
-            if self.__dns_client is None:
-                self.__dns_client = AsyncClient()
-
-            if self.__server_key is not None:
-                s = s2.sign(self.__server_key)
-                data = m1.encrypt(s, domain.encode(), serialize({'domain': domain}), hash(self.__server_key))
-                payload = {'sign': {'alg': 'KeyisB-c-s-m1', 'data': s}, 'data': data}
-            else:
-                payload = None
-
-            r1 = await self.__dns_client.request(GNRequest('GET', Url(f'gn://{self.__dns_core__ipv4}/getIp?d={domain}'), payload=payload), keep_alive=keep_alive)
-
-            if r1.command != 'ok':
-                raise GNExceptions.ConnectionError.dns.data
-
-            if r1.payload is None:
-                raise GNExceptions.ConnectionError.dns.data
-
-            r1_data = r1.payload
-
-            result = r1_data['ip'] + ':' + str(r1_data['port']) # type: ignore
-
-            self._dns_cache.set(domain, result, r1_data.get('ttl')) # type: ignore
-
-            return result
-
-        except httpx.TimeoutException:
-            raise GNExceptions.ConnectionError.dns.timeout
-        except:
-            raise GNExceptions.ConnectionError.dns.connection
-
-    async def getGNDNS(self, domain: str, use_cache: bool = True, keep_alive: bool = False) -> str:
-        if use_cache:
-            resuilt = self._dns_cache.get(domain)
-            if resuilt is not None:
-                return resuilt
-
-        if ':' in domain and domain.split('.')[-1].split(':')[0].isdigit() and domain.split(':')[-1].isdigit():
-            return domain
-
-        if self.__dns_gn__ipv4 is None:
-            self.__dns_gn__ipv4 = await self.getCoreDNS('dns.gn')
-
-        try:
-            if self.__dns_client is None:
-                self.__dns_client = AsyncClient()
-            
-            if self.__server_key is not None:
-                payload = {'sign': {'alg': 'KeyisB-c-s-m1', 'data': s1.sign(self.__server_key)}}
-            else:
-                payload = None
-
-            r1 = await self.__dns_client.request(GNRequest('GET', Url(f'gn://{self.__dns_gn__ipv4}/getIp?d={domain}'), payload=payload), keep_alive=keep_alive)
-
-            if r1.command != 'ok':
-                raise GNExceptions.ConnectionError.dns.data
-
-            
-            if r1.payload is None:
-                raise GNExceptions.ConnectionError.dns.data
-            
-            r1_data = r1.payload
-
-            result = r1_data['ip'] + ':' + str(r1_data['port']) # type: ignore
-
-            self._dns_cache.set(domain, result, r1_data.get('ttl')) # type: ignore
-
-            return result
-
-        except httpx.TimeoutException:
-            raise GNExceptions.ConnectionError.dns.timeout
-        except:
-            raise GNExceptions.ConnectionError.dns.connection
-
-    async def getDNS(self, domain: str, use_cache: bool = True, keep_alive: bool = False):
-        if domain.endswith(('.core', '.gw', '.gn', '.cdn', '.sys', '.gwis', '.abs')):
-            return await self.getCoreDNS(domain=domain, use_cache=use_cache, keep_alive=keep_alive)
-        else:
-            return await self.getGNDNS(domain=domain, use_cache=use_cache, keep_alive=keep_alive)
+    def setKDC(self, kdc: KDCObject):
+        self._kdc = kdc
+        self._kdc._client = self
 
     def addRequestCallback(self, callback: Callable, name: str):
         self.__request_callbacks[name] = callback
@@ -262,15 +201,11 @@ class AsyncClient:
   
     async def connect(self, request: GNRequest, restart_connection: bool = False, reconnect_wait: float = 10, keep_alive: bool = True) -> 'QuicClient':
         domain = request.url.hostname
-        devLog(request, '1.2.1', 10, f'Connect to {domain}: restart_connection={restart_connection}, reconnect_wait={reconnect_wait}, keep_alive={keep_alive}')
         if not restart_connection and domain in self._active_connections:
             c = self._active_connections[domain]
-            devLog(request, '1.2.2', 10, f'Connection to {domain} found: status={c.status}')
             if c.status == 'connecting':
-                devLog(request, '1.2.3', 10, f'Waiting for connection to {domain}...')
                 try:
-                    await asyncio.wait_for(c.connect_future, reconnect_wait)
-                    devLog(request, '1.2.4', 10, f'Connected to {domain}: status={c.status}')
+                    await asyncio.wait_for(c.connect_future, reconnect_wait or self._configuration.get('L5', {}).get('connection', {}).get())
                     if c.status == 'active':
                         return c
                     elif c.status == 'connecting': # если очень долго подключаемся, то кидаем ошибку
@@ -279,19 +214,14 @@ class AsyncClient:
                     elif c.status == 'disconnect':
                         raise GNExceptions.ConnectionError.client.connection
                 except:
-                    devLog(request, '1.2.5', 10, f'Connection to {domain} failed or timed out.')
                     await self.disconnect(domain)
-                        
             else:
                 return c
 
-        c = QuicClient()
-        c.status = 'connecting'
+        c = QuicClient(self, domain)
         self._active_connections[domain] = c
 
-        devLog(request, '1.2.6', 10, f'Connecting to {domain}...')
-        data = await self.getDNS(domain)
-        devLog(request, '1.2.7', 10, f'Got DNS for {domain}: {data}')
+        data = await self.getDNS(domain, raise_errors=True)
 
         data = data.split(':')
 
@@ -301,8 +231,6 @@ class AsyncClient:
             self._active_connections.pop(domain)
 
         c._disconnect_signal = f # type: ignore
-        c._domain = domain # type: ignore
-        devLog(request, '1.2.8', 10, f'Creating QuicClient for {domain}...')
         await c.connect(data[0], int(data[1]), keep_alive=keep_alive)
         await c.connect_future
 
@@ -324,31 +252,41 @@ class AsyncClient:
             if request.cookies is not None:
                 data: Optional[dict] = request.cookies.get('gn', {}).get('request', {}).get('transport', {}).get('::dev')
                 if data is not None:
-                    data['params']['logs']['data'] = []
-                    data['params']['data']['data'] = {}
-                    request._devDataLog = data['params']['logs']['data']
-                    request._devDataLogLevel = _log_levels[data['params']['logs']['data']]
-                    request._devData = data['params']['data']['data']
-                    request._devDataRange = data['params']['range']
+                    if 'netstat' in data:
+                        if 'way' in data['netstat']:
+                            if 'data' not in data['netstat']['way']:
+                                data['netstat']['way']['data'] = []
+
+
+
+                #     data['params']['logs']['data'] = []
+                #     data['params']['data']['data'] = {}
+                #     request._devDataLog = data['params']['logs']['data']
+                #     request._devDataLogLevel = _log_levels[data['params']['logs']['data']]
+                #     request._devData = data['params']['data']['data']
+                #     request._devDataRange = data['params']['range']
 
         return request
 
     async def request(self, request: Union[GNRequest, AsyncGenerator[GNRequest, Any]], keep_alive: bool = True, restart_connection: bool = False, reconnect_wait: float = 10) -> GNResponse:
-        devLog(request, '1.1.1', 10, f'Request starting... {request}: keep_alive={keep_alive}, restart_connection={restart_connection}, reconnect_wait={reconnect_wait}')
 
         if isinstance(request, GNRequest):
-            devLog(request, '1.1.2', 10, 'Request is GNRequest')
             
             request = await self._resolve_requests_transport(request)
-
-            c = await self.connect(request, restart_connection, reconnect_wait, keep_alive=keep_alive)
-            devLog(request, '1.1.3', 10, f'Connected: {c.status}')
+            try:
+                c = await self.connect(request, restart_connection, reconnect_wait, keep_alive=keep_alive)
+            except BaseException as e:
+                if isinstance(e, GNResponse):
+                    return e
+                else:
+                    return GNResponse(str(e), payload=traceback.format_exc())
 
 
             for f in self.__request_callbacks.values():
                 asyncio.create_task(f(request))
-
+            logger.debug(f'Request: {request.method} {request.url}')
             r = await c.asyncRequest(request)
+            logger.debug(f'Response: {request.method} {request.url} -> {r.command} {r.payload if len(str(r.payload)) < 256 else ''}')
 
             for f in self.__response_callbacks.values():
                 asyncio.create_task(f(r))
@@ -388,6 +326,76 @@ class AsyncClient:
             return r
 
 
+
+    def isDNSCore(self, domain: str) -> bool:
+        return domain.endswith(('.core', '.gw', '.gn', '.cdn', '.sys', '.gwis', '.abs', '.vm'))
+
+    @overload
+    async def getDNS(self, domain: str, use_cache: bool = True, keep_alive: bool = False, raise_errors: Literal[False] = False) -> GNResponse: ...
+    @overload
+    async def getDNS(self, domain: str, use_cache: bool = True, keep_alive: bool = False, raise_errors: Literal[True] = True) -> str: ...
+
+    async def getDNS(self, domain: str, use_cache: bool = True, keep_alive: bool = False, raise_errors: bool = False) -> Union[str, GNResponse]:
+        if use_cache:
+            resuilt = self._dns_cache.get(domain)
+            if resuilt is not None:
+                if raise_errors:
+                    r1_data = resuilt.payload
+                    result = r1_data['ip'] + ':' + str(r1_data['port']) # type: ignore
+                else:
+                    result = resuilt
+                return result
+            
+
+        if ':' in domain and domain.split('.')[-1].split(':')[0].isdigit() and domain.split(':')[-1].isdigit():
+            return domain
+        
+        if domain == 'api.dns.core':
+            return self.__dns_core__ipv4
+        
+        is_dns_core = self.isDNSCore(domain)
+        if not is_dns_core:
+            if self.__dns_gn__ipv4 is None:
+                self.__dns_gn__ipv4 = await self.getDNS('api.dns.gn', raise_errors=True)
+
+        if self.__dns_client is None:
+            self.__dns_client = AsyncClient()
+
+        if self._dns_key is not None:
+            s = s2.sign(self._dns_key)
+            data = m1.encrypt(s, domain.encode(), serialize({'domain': domain}), hash(self._dns_key))
+            payload = {'sign': {'alg': 'KeyisB-c-s-m1', 'data': s, 'domain': self._domain}, 'data': data}
+        else:
+            payload = None
+        
+        if is_dns_core:
+            ip_dns = self.__dns_core__ipv4
+        else:
+            ip_dns = self.__dns_gn__ipv4
+
+        r1 = await self.__dns_client.request(GNRequest('GET', Url(f'gn://{ip_dns}/getIp?d={domain}'), payload=payload), keep_alive=keep_alive)
+
+        if not r1.command:
+            if raise_errors:
+                raise r1
+            else:
+                return r1
+
+        self._dns_cache.set(domain, r1, r1.payload.get('ttl', 60)) # type: ignore
+
+        if raise_errors:
+            r1_data = r1.payload
+            result = r1_data['ip'] + ':' + str(r1_data['port']) # type: ignore
+        else:
+            result = r1
+        return result
+
+    
+
+
+
+
+
     # async def requestStream(self, request: Union[GNRequest, AsyncGenerator[GNRequest, Any]]) -> AsyncGenerator[GNResponse, None]:
     #     """
     #     Build and send a async request.
@@ -423,32 +431,28 @@ class AsyncClient:
 
     #             yield response
 
-class RawQuicClient(QuicConnectionProtocol):
+class RawQuicClient(EncryptedQuicProtocol):
 
     SYS_RATIO_NUM = 9  # SYS 9/10
     SYS_RATIO_DEN = 10
-    KEEPALIVE_INTERVAL = 10  # сек
-    KEEPALIVE_IDLE_TRIGGER = 30  # сек
 
     # ────────────────────────────────────────────────────────────────── init ─┐
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self, client: 'QuicClient', connection, stream_handler):
+        self._client = client
+        
+        dgEncryptor = DatagramEncryptor(self._client._client._kdc, selfDomain=self._client._client._domain)
+        super().__init__(connection, dgEncryptor, stream_handler)
 
         self.quicClient: QuicClient = None # type: ignore
 
-        self._sys_stream_id: int = None # type: ignore
         self._queue_sys: Deque[Tuple[int, bytes, bool]] = deque()
         self._queue_user: Deque[Tuple[int, bytes, bool]] = deque()
 
         # <‑‑ Future | Queue[bytes | None]
         self._inflight: Dict[int, Union[asyncio.Future, asyncio.Queue[Optional[GNResponse]]]] = {}
         self._inflight_streams: Dict[int, bytearray] = {}
-        self._sys_inflight: Dict[int, asyncio.Future] = {}
         self._buffer: Dict[Union[int, str], bytearray] = {}
 
-        self._sys_budget = self.SYS_RATIO_NUM
-        self._sys_id_gen = count(1)  # int64 message‑id generator
-
         self._last_activity = time.time()
         self._running = True
         self._ping_id_gen = count(1)  # int64 ping‑id generator
@@ -459,9 +463,9 @@ class RawQuicClient(QuicConnectionProtocol):
 
     async def _keepalive_loop(self):
         while self._running:
-            await asyncio.sleep(self.KEEPALIVE_INTERVAL)
+            await asyncio.sleep(self.quicClient._client._configuration.get('L5', {}).get('disconnection', {}).get('ping_check_interval', 5))
             idle_time = time.time() - self._last_activity
-            if idle_time > self.KEEPALIVE_IDLE_TRIGGER:
+            if idle_time > self.quicClient._client._configuration.get('L5', {}).get('disconnection', {}).get('ping_interval', 15):
                 self._quic.send_ping(next(self._ping_id_gen))
                 self.transmit()
                 self._last_activity = time.time()
@@ -473,86 +477,65 @@ class RawQuicClient(QuicConnectionProtocol):
     def quic_event_received(self, event: QuicEvent) -> None:  # noqa: C901
         # ─── DATA ───────────────────────────────────────────
         if isinstance(event, StreamDataReceived):
-            #print(event)
-            # SYS поток
-            if event.stream_id == self._sys_stream_id:
-                buf = self._buffer.setdefault("sys", bytearray())
+            handler = self._inflight.get(event.stream_id)
+            if handler is None:
+                return
+            
+            # Чтение в зависимости от режима
+            if not isinstance(handler, asyncio.Queue): # стрим от сервера
+                buf = self._buffer.setdefault(event.stream_id, bytearray())
                 buf.extend(event.data)
-                while True:
-                    if len(buf) < 12:
-                        break
-                    msg_id = int.from_bytes(buf[:8], "little")
-                    size = int.from_bytes(buf[8:12], "little")
-                    if len(buf) < 12 + size:
-                        break
-                    payload = bytes(buf[12 : 12 + size])
-                    del buf[: 12 + size]
-                    fut = self._sys_inflight.pop(msg_id, None) if msg_id else None
-                    if fut and not fut.done():
-                        fut.set_result(payload)
-            # USER поток
+                if event.end_stream:
+                    self._inflight.pop(event.stream_id, None)
+                    data = bytes(self._buffer.pop(event.stream_id, b""))
+                    if not handler.done():
+                        handler.set_result(data)
             else:
-                handler = self._inflight.get(event.stream_id)
-                if handler is None:
-                    return
+                raise NotImplementedError
+                # # получаем байты
+                # buf = self._buffer.setdefault(event.stream_id, bytearray())
+                # buf.extend(event.data)
+
+                # if len(buf) < 8: # не дошел даже frame пакета
+                #     return
                 
-                # Чтение в зависимости от режима
-                if isinstance(handler, asyncio.Queue): # стрим от сервера
-                    # получаем байты
+                # # получаем длинну пакета
+                # mode, stream, lenght = GNResponse.type(buf)
 
-                    buf = self._buffer.setdefault(event.stream_id, bytearray())
-                    buf.extend(event.data)
+                # if mode != 4: # не наш пакет
+                #     self._buffer.pop(event.stream_id)
+                #     return
+                
+                # if not stream: # клиент просил стрим, а сервер прислал один пакет
+                #     self._buffer.pop(event.stream_id)
+                #     return
+                
+                # # читаем пакет
+                # if len(buf) < lenght: # если пакет не весь пришел, пропускаем
+                #     return
+                
+                # # пакет пришел весь
 
-                    if len(buf) < 8: # не дошел даже frame пакета
-                        return
+                # # берем пакет
+                # data = buf[:lenght]
+
+                # # удаляем его из буфера
+                # del buf[:lenght]
                     
-                    # получаем длинну пакета
-                    mode, stream, lenght = GNResponse.type(buf)
-
-                    if mode != 4: # не наш пакет
-                        self._buffer.pop(event.stream_id)
-                        return
-                    
-                    if not stream: # клиент просил стрим, а сервер прислал один пакет
-                        self._buffer.pop(event.stream_id)
-                        return
-                    
-                    # читаем пакет
-                    if len(buf) < lenght: # если пакет не весь пришел, пропускаем
-                        return
-                    
-                    # пакет пришел весь
-
-                    # берем пакет
-                    data = buf[:lenght]
-
-                    # удаляем его из буфера
-                    del buf[:lenght]
-                        
-                    
-                    r = GNResponse.deserialize(data, 2)
-                    handler.put_nowait(r)
-                    if event.end_stream:
-                        handler.put_nowait(None)
-                        self._buffer.pop(event.stream_id)
-                        self._inflight.pop(event.stream_id, None)
+                
+                # r = GNResponse.deserialize(data, _sys_s_mode)
+                # handler.put_nowait(r)
+                # if event.end_stream:
+                #     handler.put_nowait(None)
+                #     self._buffer.pop(event.stream_id)
+                #     self._inflight.pop(event.stream_id, None)
 
 
-
-                else:  # Future
-                    buf = self._buffer.setdefault(event.stream_id, bytearray())
-                    buf.extend(event.data)
-                    if event.end_stream:
-                        self._inflight.pop(event.stream_id, None)
-                        data = bytes(self._buffer.pop(event.stream_id, b""))
-                        if not handler.done():
-                            handler.set_result(data)
+                
 
         # ─── RESET ──────────────────────────────────────────
         elif isinstance(event, StreamReset):
-            handler = self._inflight.pop(event.stream_id, None) or self._sys_inflight.pop(
-                event.stream_id, None
-            )
+            handler = self._inflight.pop(event.stream_id, None)
             if handler is None:
                 return
             if isinstance(handler, asyncio.Queue):
@@ -569,67 +552,63 @@ class RawQuicClient(QuicConnectionProtocol):
             if self.quicClient is None:
                 return
             
+            self.stop()
+            
             asyncio.create_task(self.quicClient.disconnect())
 
 
-    # ─────────────────────────────────────────── scheduler ─┤
-    def _enqueue(self, sid: int, blob: bytes, end_stream: bool, is_sys: bool):
-        (self._queue_sys if is_sys else self._queue_user).append((sid, blob, end_stream))
 
     def _schedule_flush(self):
-        while (self._queue_sys or self._queue_user) and self._quic._close_event is None:
-            q = None
-            if self._queue_sys and (self._sys_budget > 0 or not self._queue_user):
-                q = self._queue_sys
-                self._sys_budget -= 1
-            elif self._queue_user:
-                q = self._queue_user
-                self._sys_budget = self.SYS_RATIO_NUM
-            if q is None:
-                break
-            sid, blob, end_stream = q.popleft()
-            print(f'Отправка стрима {sid}')
-            self._quic.send_stream_data(sid, blob, end_stream=end_stream)
         self.transmit()
         self._activity()
 
-    # ─────────────────────────────────────────── public API ─┤
-    async def ensure_sys_stream(self):
-        if self._sys_stream_id is None:
-            self._sys_stream_id = self._quic.get_next_available_stream_id()
-            self._enqueue(self._sys_stream_id, b"", False, True)  # dummy
-            self._schedule_flush()
+    async def _resolve_requests_transport(self, request: GNRequest):
+        
+            if request.transportObject.routeProtocol.dev:
+                if request.cookies is not None:
+                    data: Optional[dict] = request.cookies.get('gn', {}).get('request', {}).get('transport', {}).get('::dev')
+                    if data is not None:
+                        if 'netstat' in data:
+                            if 'way' in data['netstat']:
+                                data['netstat']['way']['data'].append({
+                                    'object': 'GNClient',
+                                    'step': '1',
+                                    'type': 'L5',
+                                    'action': 'send',
+                                    'time': datetime.datetime.now(datetime.timezone.utc).isoformat(),
+                                    'route': str(request.route),
+                                    'method': request.method,
+                                    'url': str(request.url),
+                                })
+
 
-    async def send_sys(self, request: GNRequest, response: bool = False) -> Optional[bytes]:
-        await self.ensure_sys_stream()
-        if response:
-            msg_id = next(self._sys_id_gen)
-            blob = request.serialize(2)
-            payload = (
-                msg_id.to_bytes(8, "little") + len(blob).to_bytes(4, "little") + blob
-            )
-            fut = asyncio.get_running_loop().create_future()
-            self._sys_inflight[msg_id] = fut
-            self._enqueue(self._sys_stream_id, payload, False, True)
-            self._schedule_flush()
-            return await fut
-        payload = (0).to_bytes(8, "little") + request.serialize(2)
-        self._enqueue(self._sys_stream_id, payload, False, True)
-        self._schedule_flush()
-        return None
 
     async def request(self, request: Union[GNRequest, AsyncGenerator[GNRequest, Any]]):
         if isinstance(request, GNRequest):
-            blob = request.serialize(2)
+            await self._resolve_requests_transport(request)
+            blob = request.serialize(_sys_s_mode)
+
+            if self.quicClient._client._kdc is not None:
+                blob = await self.quicClient._client._kdc.encode(request.url.hostname, blob)
+                
             sid = self._quic.get_next_available_stream_id()
-            devLog(request, '1.3.1', 10, f'Sending request on stream {sid}')
-            self._enqueue(sid, blob, True, False)
+
+            self._quic.send_stream_data(sid, blob, end_stream=True)
             self._schedule_flush()
 
             
             fut = asyncio.get_running_loop().create_future()
             self._inflight[sid] = fut
-            return await fut
+            data = await fut
+            
+            if self.quicClient._client._kdc is not None:
+                data, domain = await self.quicClient._client._kdc.decode(data)
+
+            if data is not None:
+                r = GNResponse.deserialize(data, _sys_s_mode)
+                return r
+            else:
+                return GNResponse('gn:client:0')
         
         else:
             sid = self._quic.get_next_available_stream_id()
@@ -639,10 +618,8 @@ class RawQuicClient(QuicConnectionProtocol):
                 _last = None
                 async for req in request:
                     _last = req
-                    blob = req.serialize(2)
-                    self._enqueue(sid, blob, False, False)
-
-
+                    blob = req.serialize(_sys_s_mode)
+                    self._quic.send_stream_data(sid, blob, end_stream=False)
                     self._schedule_flush()
 
                     print(f'Отправлен stream запрос {req}')
@@ -650,8 +627,8 @@ class RawQuicClient(QuicConnectionProtocol):
 
                 _last.setPayload(None)
                 _last.setMethod('gn:end-stream')
-                blob = _last.serialize(2)
-                self._enqueue(sid, blob, True, False)
+                blob = _last.serialize(_sys_s_mode)
+                self._quic.send_stream_data(sid, blob, end_stream=True)
                 self._schedule_flush()
             
             asyncio.create_task(_stream_sender(sid, request))
@@ -661,75 +638,76 @@ class RawQuicClient(QuicConnectionProtocol):
             self._inflight[sid] = fut
             return await fut
     
-    async def requestStream(self, request: Union[GNRequest, AsyncGenerator[GNRequest, Any]]) -> asyncio.Queue[GNResponse]:
-        if isinstance(request, GNRequest):
-            blob = request.serialize(2)
-            sid = self._quic.get_next_available_stream_id()
-            self._enqueue(sid, blob, False, False)
-            self._schedule_flush()
+    # async def requestStream(self, request: Union[GNRequest, AsyncGenerator[GNRequest, Any]]) -> asyncio.Queue[GNResponse]:
+    #     if isinstance(request, GNRequest):
+    #         blob = request.serialize(_sys_s_mode)
+    #         sid = self._quic.get_next_available_stream_id()
+    #         self._enqueue(sid, blob, False, False)
+    #         self._schedule_flush()
 
             
-            q = asyncio.Queue()
-            self._inflight[sid] = q
-            return q
+    #         q = asyncio.Queue()
+    #         self._inflight[sid] = q
+    #         return q
             
-        else:
-            sid = self._quic.get_next_available_stream_id()
+    #     else:
+    #         sid = self._quic.get_next_available_stream_id()
 
-            async def _stream_sender(sid, request: AsyncGenerator[GNRequest, Any]):
-                _last = None
-                async for req in request:
-                    _last = req
-                    blob = req.serialize(2)
-                    self._enqueue(sid, blob, False, False)
+    #         async def _stream_sender(sid, request: AsyncGenerator[GNRequest, Any]):
+    #             _last = None
+    #             async for req in request:
+    #                 _last = req
+    #                 blob = req.serialize(_sys_s_mode)
+    #                 self._enqueue(sid, blob, False, False)
 
 
-                    self._schedule_flush()
+    #                 self._schedule_flush()
 
-                    print(f'Отправлен stream запрос {req}')
+    #                 print(f'Отправлен stream запрос {req}')
                 
 
-                _last.setPayload(None)
-                _last.setMethod('gn:end-stream')
-                blob = _last.serialize(2)
-                self._enqueue(sid, blob, True, False)
-                self._schedule_flush()
+    #             _last.setPayload(None)
+    #             _last.setMethod('gn:end-stream')
+    #             blob = _last.serialize(_sys_s_mode)
+    #             self._enqueue(sid, blob, True, False)
+    #             self._schedule_flush()
             
-            asyncio.create_task(_stream_sender(sid, request))
+    #         asyncio.create_task(_stream_sender(sid, request))
 
                 
-            q = asyncio.Queue()
-            self._inflight[sid] = q
-            return q
+    #         q = asyncio.Queue()
+    #         self._inflight[sid] = q
+    #         return q
 
         
 
 class QuicClient:
     """Обёртка‑фасад над RawQuicClient."""
 
-    def __init__(self):
+    def __init__(self, Client: AsyncClient, domain: str):
+        self._client = Client
+        self.domain = domain
         self._quik_core: Optional[RawQuicClient] = None
         self._client_cm = None
         self._disconnect_signal = None
-        self._domain = None
 
-        self.status: Literal['active', 'connecting', 'disconnect']
+        self.status: Literal['active', 'connecting', 'disconnect'] = 'connecting'
 
         self.connect_future = asyncio.get_event_loop().create_future()
-        self.connection_time: datetime.datetime = None # type: ignore
 
     async def connect(self, ip: str, port: int, keep_alive: bool = True):
         self.status = 'connecting'
-        self.connection_time = datetime.datetime.now()
         cfg = QuicConfiguration(is_client=True, alpn_protocols=["gn:backend"])
         cfg.load_verify_locations(cadata=crt_client)
-        cfg.idle_timeout = 40
+        cfg.idle_timeout = self._client._configuration.get('L5', {}).get('disconnection', {}).get('idle_timeout', 60)
+
+        await self._client._kdc.checkKey(self.domain)
 
         self._client_cm = connect(
             ip,
             port,
             configuration=cfg,
-            create_protocol=RawQuicClient,
+            create_protocol=lambda connection, stream_handler: RawQuicClient(self, connection=connection,stream_handler=stream_handler),
             wait_connected=True,
         )
 
@@ -758,7 +736,7 @@ class QuicClient:
         
 
         if self._disconnect_signal is not None:
-            self._disconnect_signal(self._domain)
+            self._disconnect_signal(self.domain)
         
 
         if self._quik_core is not None:
@@ -770,8 +748,6 @@ class QuicClient:
                 else:
                     fut.set_exception(Exception)
 
-            for fut in self._quik_core._sys_inflight.values():
-                fut.set_exception(Exception)
 
 
             self._quik_core.close()
@@ -783,21 +759,17 @@ class QuicClient:
             raise RuntimeError("Not connected")
         
         resp = await self._quik_core.request(request)
-        r = GNResponse.deserialize(resp, 2)
-        devLog(request, '1.4.1', 10, f'Response received: {r}')
-        return r
+        return resp
 
-    async def asyncRequestStream(self, request: Union[GNRequest, AsyncGenerator[GNRequest, Any]]) -> AsyncGenerator[GNResponse, None]:
+    # async def asyncRequestStream(self, request: Union[GNRequest, AsyncGenerator[GNRequest, Any]]) -> AsyncGenerator[GNResponse, None]:
         
-        if self._quik_core is None:
-            raise RuntimeError("Not connected")
-
-        queue = await self._quik_core.requestStream(request)
-
-        while True:
-            chunk = await queue.get()
-            if chunk is None or chunk.command == 'gn:end-stream':
-                break
-            yield chunk
+    #     if self._quik_core is None:
+    #         raise RuntimeError("Not connected")
 
+    #     queue = await self._quik_core.requestStream(request)
 
+    #     while True:
+    #         chunk = await queue.get()
+    #         if chunk is None or chunk.command == 'gn:end-stream':
+    #             break
+    #         yield chunk
\ No newline at end of file
